@@ -23,6 +23,15 @@ lenuni_values = {'unknown': 0,
                  'meter': 2
                  }
 
+unit_abbreviations = {                 
+                 'feet': 'ft',
+                 'meters': 'm',
+                 'centimeters': 'cm',
+                 'millimeters': 'mm',
+                 'kilometers': 'km',
+                 'inches': 'in',
+                 'miles': 'mi',}
+
 fullnames = {'unknown', 'undefined', 'feet', 'meters', 'centimeters',
              'millimeters', 'inches', 'miles', 'kilometers',
              'seconds', 'minutes', 'hours', 'days', 'years'}
@@ -50,6 +59,11 @@ itmuni_values = {"unknown": 0,
                  "hours": 3,
                  "days": 4,
                  "years": 5,
+                 "second": 1,
+                 "minute": 2,
+                 "hour": 3,
+                 "day": 4,
+                 "year": 5,
                  "s": 1,
                  "m": 2,
                  "h": 3,
@@ -128,7 +142,7 @@ def convert_time_units(itmuni1, itmuni2):
              (2, 5): 1 / (1440 * yearlen),
              (3, 4): 1 / 24,
              (3, 5): 1 / (24 * yearlen),
-             (4, 5): yearlen}
+             (4, 5): 1/ yearlen}
     convert_time_units = np.ones((6, 6), dtype=float)
     for (u0, u1), mult in mults.items():
         convert_time_units[u0, u1] = mult
@@ -272,7 +286,7 @@ def convert_flux_units(input_length_units, input_time_units,
 
     lmult = convert_length_units(input_length_units, output_length_units)
     tmult = convert_time_units(input_time_units, output_time_units)
-    return lmult * tmult
+    return lmult / tmult
 
 
 def parse_length_units(text, text_output=True):
